@@ -93,6 +93,70 @@ class Test(unittest.TestCase):
         self.assertEqual(cl.CL_PROFILING_COMMAND_START, 0x1282)
         self.assertEqual(cl.CL_PROFILING_COMMAND_END, 0x1283)
 
+    def test_error_codes(self):
+        self.assertEqual(cl.CL_SUCCESS, 0)
+        self.assertEqual(cl.CL_DEVICE_NOT_FOUND, -1)
+        self.assertEqual(cl.CL_DEVICE_NOT_AVAILABLE, -2)
+        self.assertEqual(cl.CL_COMPILER_NOT_AVAILABLE, -3)
+        self.assertEqual(cl.CL_MEM_OBJECT_ALLOCATION_FAILURE, -4)
+        self.assertEqual(cl.CL_OUT_OF_RESOURCES, -5)
+        self.assertEqual(cl.CL_OUT_OF_HOST_MEMORY, -6)
+        self.assertEqual(cl.CL_PROFILING_INFO_NOT_AVAILABLE, -7)
+        self.assertEqual(cl.CL_MEM_COPY_OVERLAP, -8)
+        self.assertEqual(cl.CL_IMAGE_FORMAT_MISMATCH, -9)
+        self.assertEqual(cl.CL_IMAGE_FORMAT_NOT_SUPPORTED, -10)
+        self.assertEqual(cl.CL_BUILD_PROGRAM_FAILURE, -11)
+        self.assertEqual(cl.CL_MAP_FAILURE, -12)
+        self.assertEqual(cl.CL_MISALIGNED_SUB_BUFFER_OFFSET, -13)
+        self.assertEqual(cl.CL_EXEC_STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST, -14)
+        self.assertEqual(cl.CL_COMPILE_PROGRAM_FAILURE, -15)
+        self.assertEqual(cl.CL_LINKER_NOT_AVAILABLE, -16)
+        self.assertEqual(cl.CL_LINK_PROGRAM_FAILURE, -17)
+        self.assertEqual(cl.CL_DEVICE_PARTITION_FAILED, -18)
+        self.assertEqual(cl.CL_KERNEL_ARG_INFO_NOT_AVAILABLE, -19)
+
+        self.assertEqual(cl.CL_INVALID_VALUE, -30)
+        self.assertEqual(cl.CL_INVALID_DEVICE_TYPE, -31)
+        self.assertEqual(cl.CL_INVALID_PLATFORM, -32)
+        self.assertEqual(cl.CL_INVALID_DEVICE, -33)
+        self.assertEqual(cl.CL_INVALID_CONTEXT, -34)
+        self.assertEqual(cl.CL_INVALID_QUEUE_PROPERTIES, -35)
+        self.assertEqual(cl.CL_INVALID_COMMAND_QUEUE, -36)
+        self.assertEqual(cl.CL_INVALID_HOST_PTR, -37)
+        self.assertEqual(cl.CL_INVALID_MEM_OBJECT, -38)
+        self.assertEqual(cl.CL_INVALID_IMAGE_FORMAT_DESCRIPTOR, -39)
+        self.assertEqual(cl.CL_INVALID_IMAGE_SIZE, -40)
+        self.assertEqual(cl.CL_INVALID_SAMPLER, -41)
+        self.assertEqual(cl.CL_INVALID_BINARY, -42)
+        self.assertEqual(cl.CL_INVALID_BUILD_OPTIONS, -43)
+        self.assertEqual(cl.CL_INVALID_PROGRAM, -44)
+        self.assertEqual(cl.CL_INVALID_PROGRAM_EXECUTABLE, -45)
+        self.assertEqual(cl.CL_INVALID_KERNEL_NAME, -46)
+        self.assertEqual(cl.CL_INVALID_KERNEL_DEFINITION, -47)
+        self.assertEqual(cl.CL_INVALID_KERNEL, -48)
+        self.assertEqual(cl.CL_INVALID_ARG_INDEX, -49)
+        self.assertEqual(cl.CL_INVALID_ARG_VALUE, -50)
+        self.assertEqual(cl.CL_INVALID_ARG_SIZE, -51)
+        self.assertEqual(cl.CL_INVALID_KERNEL_ARGS, -52)
+        self.assertEqual(cl.CL_INVALID_WORK_DIMENSION, -53)
+        self.assertEqual(cl.CL_INVALID_WORK_GROUP_SIZE, -54)
+        self.assertEqual(cl.CL_INVALID_WORK_ITEM_SIZE, -55)
+        self.assertEqual(cl.CL_INVALID_GLOBAL_OFFSET, -56)
+        self.assertEqual(cl.CL_INVALID_EVENT_WAIT_LIST, -57)
+        self.assertEqual(cl.CL_INVALID_EVENT, -58)
+        self.assertEqual(cl.CL_INVALID_OPERATION, -59)
+        self.assertEqual(cl.CL_INVALID_GL_OBJECT, -60)
+        self.assertEqual(cl.CL_INVALID_BUFFER_SIZE, -61)
+        self.assertEqual(cl.CL_INVALID_MIP_LEVEL, -62)
+        self.assertEqual(cl.CL_INVALID_GLOBAL_WORK_SIZE, -63)
+        self.assertEqual(cl.CL_INVALID_PROPERTY, -64)
+        self.assertEqual(cl.CL_INVALID_IMAGE_DESCRIPTOR, -65)
+        self.assertEqual(cl.CL_INVALID_COMPILER_OPTIONS, -66)
+        self.assertEqual(cl.CL_INVALID_LINKER_OPTIONS, -67)
+        self.assertEqual(cl.CL_INVALID_DEVICE_PARTITION_COUNT, -68)
+        self.assertEqual(cl.CL_INVALID_PIPE_SIZE, -69)
+        self.assertEqual(cl.CL_INVALID_DEVICE_QUEUE, -70)
+
     def test_dump_devices(self):
         platforms = cl.Platforms()
         s = platforms.dump_devices()
